@@ -3,12 +3,12 @@ from pydantic import BaseModel, Field
 
 class ConnectorPaginationOptions(BaseModel):
     page: int = Field(default=1, ge=1)
-    page_size: int = Field(default=25, gt=0, le=500)
+    page_size: int = Field(default=25, ge=1, le=500)
 
     @property
     def page_params(self) -> tuple[int, int]:
         if self.page is not None:
-            return self.page, self.page_size
+            return (self.page, self.page_size)
         else:
             raise ValueError(
                 "Pagination options must be set to return a page and page size",
@@ -47,7 +47,6 @@ SNOWFLAKE_CONNECTOR_AUTHENTICATOR_FIELD = "authenticator"
 SNOWFLAKE_CONNECTOR_PRIVATE_KEY_FIELD = "private_key"
 SNOWFLAKE_CONNECTOR_PRIVATE_KEY_PASSPHRASE_FIELD = "private_key_passphrase"
 
-
 # dataset (connector type dependent) constants
 SHIELD_DATASET_TASK_ID_FIELD = "task_id"
 BUCKET_BASED_DATASET_FILE_PREFIX_FIELD = "file_prefix"
